@@ -15,17 +15,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
+
+#include <xapian.h>
+
 #include "collectionindexer.h"
+#include "xapiandocument.h"
 
 #include <QString>
 #include <QStringList>
-#include <xapian.h>
 #include <AkonadiCore/collectionidentificationattribute.h>
 #include <AkonadiCore/AttributeFactory>
-#include <xapiandocument.h>
+
 #include "akonadi_indexer_agent_debug.h"
 
 CollectionIndexer::CollectionIndexer(const QString &path)
